package de.fraunhofer.iem.app.tool.enumeration

import de.fraunhofer.iem.app.kpi.enumeration.KpiKind
import de.fraunhofer.iem.app.tool.dto.ToolDto

enum class ToolType {
    ORT {
        override fun toViewModel(): ToolDto {
            return ToolDto(
                name = this.getName(),
                relevantKpis = listOf(
                    KpiKind.MAXIMAL_VULNERABILITY.getName(),
                    KpiKind.VULNERABILITY_SCORE.getName(),
                    KpiKind.SECURITY.getName()
                ),
                description = "The OSS Review Toolkit (ORT) provides information about dependencies." +
                    "For more information see https://github.com/oss-review-toolkit/ort.",
                toolType = ORT
            )
        }

        override fun getName(): String {
            return "ORT"
        }
    },
    OCCMD {
        override fun toViewModel(): ToolDto {
            return ToolDto(
                name = this.getName(),
                relevantKpis = listOf(
                    KpiKind.SECURITY.getName(),
                    KpiKind.PROCESS_TRANSPARENCY.getName(),
                    KpiKind.PROCESS_COMPLIANCE.getName(),
                    KpiKind.SECRETS.getName(),
                    KpiKind.COMMENTS_IN_CODE.getName(),
                    KpiKind.DOCUMENTATION.getName(),
                    KpiKind.SAST_USAGE.getName(),
                    KpiKind.CHECKED_IN_BINARIES.getName()
                ),
                description = "The OCCMD provides various information about the analyzed project." +
                    "For more information see https://gitlab.opencode.de/opencode-analyzer/occmd-public.",
                toolType = OCCMD

            )
        }

        override fun getName(): String {
            return "OCCMD"
        }
    },
    Gitlab {
        override fun toViewModel(): ToolDto {
            return ToolDto(
                name = this.getName(),
                relevantKpis = listOf(
                    KpiKind.PROCESS_TRANSPARENCY.getName(),
                    KpiKind.PROCESS_COMPLIANCE.getName(),
                    KpiKind.NUMBER_OF_COMMITS.getName(),
                    KpiKind.NUMBER_OF_SIGNED_COMMITS.getName(),
                    KpiKind.DOCUMENTATION.getName(),
                ),
                description = "The Gitlab API is used to derive information about, e.g., the project's compliance" +
                    "to OpenCoDE's platform rules.",
                toolType = Gitlab
            )
        }

        override fun getName(): String {
            return "Gitlab API"
        }
    };

    abstract fun toViewModel(): ToolDto
    abstract fun getName(): String
}
